@@ -52,7 +52,7 @@ def preStart():
                         shutil.copy(os.path.join(src, item), target)
                         cmd = 'chmod 777 '+target
                         subprocess.call([cmd],shell=True)
-                    elif item.endswith('.py') or item.endswith('.md5') or item.endswith('.png') or item.endswith('.mp4') or item.endswith('.html'):
+                    elif item.endswith('.py') or item.endswith('.md5') or item.endswith('.ui') or item.endswith('.mp4') or item.endswith('.html'):
                         print('Copying to local laucher folder',item)
                         shutil.copy(os.path.join(src, item), os.path.join(LOCAL_LAUCHER_FOLDER, item))
     except Exception as e:
