@@ -13,7 +13,7 @@ sys.path.insert(0, parentdir)
 from test_handler.i2c_lib import i2c_device
 from test_handler.cassette_polling import CassettePolling
 from define import *
-
+from main_paras import getTestMode
 # from smbus import SMBus
 # import sys
 # sys.path.append('/home/pi/gxf/python/spotii')
@@ -120,23 +120,30 @@ class TestChipHandlerThread (threading.Thread):
     def resultReport(self, result):
         if Negative_test_result == result[RESULT_ERROR_CODE] or Positive_test_result == result[RESULT_ERROR_CODE]:
             self.qCom.put(result)
+        print('put result',result)
         self.qGui.put(result)
         
     def putToResultList(self, result):     #There is nothing for RESULT_CASSETTE_ID if message is from sub thread. message from communication must have something on RESULT_CASSETTE_ID 
-      
+        #print('in putToResultList', result)
         if result[RESULT_ERROR_CODE] == DEVICE_STATE_TAKING_PHOTO:
             self.checkingStart(result[RESULT_SLOT_NUMBER])
             self.qGui.put(result)
+        elif result[RESULT_ERROR_CODE] == DEVICE_STATE_MANUAL_FLIP:
+            #print('manual flip')
+            self.qGui.put(result)
+        elif result[RESULT_ERROR_CODE] == DEVICE_STATE_MANUAL_INVALID_QR:
+            self.qGui.put(result)
         elif result[RESULT_CASSETTE_ID] == '':
             self.qGui.put(result)
         elif self.startCheck[result[RESULT_SLOT_NUMBER]] == True:
-            if len(self.checkingResult[result[RESULT_SLOT_NUMBER]]) == 0 and (Negative_test_result == result[RESULT_ERROR_CODE] or Positive_test_result == result[RESULT_ERROR_CODE]):
+            
+            #print('test mode',getTestMode())
+            #if len(self.checkingResult[result[RESULT_SLOT_NUMBER]]) == 0 and (Negative_test_result == result[RESULT_ERROR_CODE] or Positive_test_result == result[RESULT_ERROR_CODE]):
+            if getTestMode()==TEST_MODE_SPEED:
                 self.resultReport(result)
                 self.checkingStop(result[RESULT_SLOT_NUMBER])
                 return;
             
-            
-            
             if Negative_test_result == result[RESULT_ERROR_CODE] or Control_area_not_found == result[RESULT_ERROR_CODE] :                                
                 self.checkingResult[result[RESULT_SLOT_NUMBER]].append(result)
                 if len(self.checkingResult[result[RESULT_SLOT_NUMBER]]) == len(PHOTO_TAKING_GAPS)+1:
